@@ -97,6 +97,14 @@ pub enum DataType {
     TinyInt(Option<u64>),
     /// Unsigned tiny integer with optional display width e.g. TINYINT UNSIGNED or TINYINT(3) UNSIGNED
     UnsignedTinyInt(Option<u64>),
+    /// Int2 as alias for SmallInt in [postgresql]
+    /// Note: Int2 mean 2 bytes in postgres (not 2 bits)
+    /// Int2 with optional display width e.g. INT2 or INT2(5)
+    ///
+    /// [postgresql]: https://www.postgresql.org/docs/15/datatype.html
+    Int2(Option<u64>),
+    /// Unsigned Int2 with optional display width e.g. INT2 Unsigned or INT2(5) Unsigned
+    UnsignedInt2(Option<u64>),
     /// Small integer with optional display width e.g. SMALLINT or SMALLINT(5)
     SmallInt(Option<u64>),
     /// Unsigned small integer with optional display width e.g. SMALLINT UNSIGNED or SMALLINT(5) UNSIGNED
@@ -109,20 +117,44 @@ pub enum DataType {
     ///
     /// [1]: https://dev.mysql.com/doc/refman/8.0/en/integer-types.html
     UnsignedMediumInt(Option<u64>),
-    /// Integer with optional display width e.g. INT or INT(11)
+    /// Int with optional display width e.g. INT or INT(11)
     Int(Option<u64>),
+    /// Int4 as alias for Integer in [postgresql]
+    /// Note: Int4 mean 4 bytes in postgres (not 4 bits)
+    /// Int4 with optional display width e.g. Int4 or Int4(11)
+    ///
+    /// [postgresql]: https://www.postgresql.org/docs/15/datatype.html
+    Int4(Option<u64>),
     /// Integer with optional display width e.g. INTEGER or INTEGER(11)
     Integer(Option<u64>),
-    /// Unsigned integer with optional display width e.g. INT UNSIGNED or INT(11) UNSIGNED
+    /// Unsigned int with optional display width e.g. INT UNSIGNED or INT(11) UNSIGNED
     UnsignedInt(Option<u64>),
+    /// Unsigned int4 with optional display width e.g. INT4 UNSIGNED or INT4(11) UNSIGNED
+    UnsignedInt4(Option<u64>),
     /// Unsigned integer with optional display width e.g. INTGER UNSIGNED or INTEGER(11) UNSIGNED
     UnsignedInteger(Option<u64>),
     /// Big integer with optional display width e.g. BIGINT or BIGINT(20)
     BigInt(Option<u64>),
     /// Unsigned big integer with optional display width e.g. BIGINT UNSIGNED or BIGINT(20) UNSIGNED
     UnsignedBigInt(Option<u64>),
+    /// Int8 as alias for Bigint in [postgresql]
+    /// Note: Int8 mean 8 bytes in postgres (not 8 bits)
+    /// Int8 with optional display width e.g. INT8 or INT8(11)
+    ///
+    /// [postgresql]: https://www.postgresql.org/docs/15/datatype.html
+    Int8(Option<u64>),
+    /// Unsigned Int8 with optional display width e.g. INT8 UNSIGNED or INT8(11) UNSIGNED
+    UnsignedInt8(Option<u64>),
+    /// Float4 as alias for Real in [postgresql]
+    ///
+    /// [postgresql]: https://www.postgresql.org/docs/15/datatype.html
+    Float4,
     /// Floating point e.g. REAL
     Real,
+    /// Float8 as alias for Double in [postgresql]
+    ///
+    /// [postgresql]: https://www.postgresql.org/docs/15/datatype.html
+    Float8,
     /// Double
     Double,
     /// Double PRECISION e.g. [standard], [postgresql]
@@ -130,6 +162,10 @@ pub enum DataType {
     /// [standard]: https://jakewheat.github.io/sql-overview/sql-2016-foundation-grammar.html#approximate-numeric-type
     /// [postgresql]: https://www.postgresql.org/docs/current/datatype-numeric.html
     DoublePrecision,
+    /// Bool as alias for Boolean in [postgresql]
+    ///
+    /// [postgresql]: https://www.postgresql.org/docs/15/datatype.html
+    Bool,
     /// Boolean
     Boolean,
     /// Date
@@ -213,6 +249,12 @@ impl fmt::Display for DataType {
             DataType::UnsignedTinyInt(zerofill) => {
                 format_type_with_optional_length(f, "TINYINT", zerofill, true)
             }
+            DataType::Int2(zerofill) => {
+                format_type_with_optional_length(f, "INT2", zerofill, false)
+            }
+            DataType::UnsignedInt2(zerofill) => {
+                format_type_with_optional_length(f, "INT2", zerofill, true)
+            }
             DataType::SmallInt(zerofill) => {
                 format_type_with_optional_length(f, "SMALLINT", zerofill, false)
             }
@@ -229,6 +271,12 @@ impl fmt::Display for DataType {
             DataType::UnsignedInt(zerofill) => {
                 format_type_with_optional_length(f, "INT", zerofill, true)
             }
+            DataType::Int4(zerofill) => {
+                format_type_with_optional_length(f, "INT4", zerofill, false)
+            }
+            DataType::UnsignedInt4(zerofill) => {
+                format_type_with_optional_length(f, "INT4", zerofill, true)
+            }
             DataType::Integer(zerofill) => {
                 format_type_with_optional_length(f, "INTEGER", zerofill, false)
             }
@@ -241,9 +289,18 @@ impl fmt::Display for DataType {
             DataType::UnsignedBigInt(zerofill) => {
                 format_type_with_optional_length(f, "BIGINT", zerofill, true)
             }
+            DataType::Int8(zerofill) => {
+                format_type_with_optional_length(f, "INT8", zerofill, false)
+            }
+            DataType::UnsignedInt8(zerofill) => {
+                format_type_with_optional_length(f, "INT8", zerofill, true)
+            }
             DataType::Real => write!(f, "REAL"),
+            DataType::Float4 => write!(f, "FLOAT4"),
             DataType::Double => write!(f, "DOUBLE"),
+            DataType::Float8 => write!(f, "FLOAT8"),
             DataType::DoublePrecision => write!(f, "DOUBLE PRECISION"),
+            DataType::Bool => write!(f, "BOOL"),
             DataType::Boolean => write!(f, "BOOLEAN"),
             DataType::Date => write!(f, "DATE"),
             DataType::Time(precision, timezone_info) => {
