@@ -12,7 +12,7 @@
 
 //! Recursive visitors for ast Nodes. See [`Visitor`] for more details.
 
-use crate::ast::{Expr, ObjectName, Statement};
+use crate::ast::{Expr, ObjectName, Statement, TableFactor};
 use core::ops::ControlFlow;
 
 /// A type that can be visited by a [`Visitor`]. See [`Visitor`] for
@@ -115,8 +115,8 @@ visit_noop!(bigdecimal::BigDecimal);
 
 /// A visitor that can be used to walk an AST tree.
 ///
-/// `previst_` methods are invoked before visiting all children of the
-/// node and `postvisit_` methods are invoked after visiting all
+/// `pre_visit_` methods are invoked before visiting all children of the
+/// node and `post_visit_` methods are invoked after visiting all
 /// children of the node.
 ///
 /// # See also
@@ -139,7 +139,7 @@ visit_noop!(bigdecimal::BigDecimal);
 /// }
 ///
 /// // Visit relations and exprs before children are visited (depth first walk)
-/// // Note you can also visit statements and visit exprs after children have been visitoed
+/// // Note you can also visit statements and visit exprs after children have been visited
 /// impl Visitor for V {
 ///   type Break = ();
 ///
@@ -189,6 +189,16 @@ pub trait Visitor {
         ControlFlow::Continue(())
     }
 
+    /// Invoked for any table factors that appear in the AST before visiting children
+    fn pre_visit_table_factor(&mut self, _table_factor: &TableFactor) -> ControlFlow<Self::Break> {
+        ControlFlow::Continue(())
+    }
+
+    /// Invoked for any table factors that appear in the AST after visiting children
+    fn post_visit_table_factor(&mut self, _table_factor: &TableFactor) -> ControlFlow<Self::Break> {
+        ControlFlow::Continue(())
+    }
+
     /// Invoked for any expressions that appear in the AST before visiting children
     fn pre_visit_expr(&mut self, _expr: &Expr) -> ControlFlow<Self::Break> {
         ControlFlow::Continue(())
@@ -212,8 +222,8 @@ pub trait Visitor {
 
 /// A visitor that can be used to mutate an AST tree.
 ///
-/// `previst_` methods are invoked before visiting all children of the
-/// node and `postvisit_` methods are invoked after visiting all
+/// `pre_visit_` methods are invoked before visiting all children of the
+/// node and `post_visit_` methods are invoked after visiting all
 /// children of the node.
 ///
 /// # See also
@@ -267,6 +277,22 @@ pub trait VisitorMut {
         ControlFlow::Continue(())
     }
 
+    /// Invoked for any table factors that appear in the AST before visiting children
+    fn pre_visit_table_factor(
+        &mut self,
+        _table_factor: &mut TableFactor,
+    ) -> ControlFlow<Self::Break> {
+        ControlFlow::Continue(())
+    }
+
+    /// Invoked for any table factors that appear in the AST after visiting children
+    fn post_visit_table_factor(
+        &mut self,
+        _table_factor: &mut TableFactor,
+    ) -> ControlFlow<Self::Break> {
+        ControlFlow::Continue(())
+    }
+
     /// Invoked for any expressions that appear in the AST before visiting children
     fn pre_visit_expr(&mut self, _expr: &mut Expr) -> ControlFlow<Self::Break> {
         ControlFlow::Continue(())
@@ -609,6 +635,24 @@ mod tests {
             ControlFlow::Continue(())
         }
 
+        fn pre_visit_table_factor(
+            &mut self,
+            table_factor: &TableFactor,
+        ) -> ControlFlow<Self::Break> {
+            self.visited
+                .push(format!("PRE: TABLE FACTOR: {table_factor}"));
+            ControlFlow::Continue(())
+        }
+
+        fn post_visit_table_factor(
+            &mut self,
+            table_factor: &TableFactor,
+        ) -> ControlFlow<Self::Break> {
+            self.visited
+                .push(format!("POST: TABLE FACTOR: {table_factor}"));
+            ControlFlow::Continue(())
+        }
+
         fn pre_visit_expr(&mut self, expr: &Expr) -> ControlFlow<Self::Break> {
             self.visited.push(format!("PRE: EXPR: {expr}"));
             ControlFlow::Continue(())
@@ -647,22 +691,28 @@ mod tests {
     fn test_sql() {
         let tests = vec![
             (
-                "SELECT * from table_name",
+                "SELECT * from table_name as my_table",
                 vec![
-                    "PRE: STATEMENT: SELECT * FROM table_name",
+                    "PRE: STATEMENT: SELECT * FROM table_name AS my_table",
+                    "PRE: TABLE FACTOR: table_name AS my_table",
                     "PRE: RELATION: table_name",
                     "POST: RELATION: table_name",
-                    "POST: STATEMENT: SELECT * FROM table_name",
+                    "POST: TABLE FACTOR: table_name AS my_table",
+                    "POST: STATEMENT: SELECT * FROM table_name AS my_table",
                 ],
             ),
             (
                 "SELECT * from t1 join t2 on t1.id = t2.t1_id",
                 vec![
                     "PRE: STATEMENT: SELECT * FROM t1 JOIN t2 ON t1.id = t2.t1_id",
+                    "PRE: TABLE FACTOR: t1",
                     "PRE: RELATION: t1",
                     "POST: RELATION: t1",
+                    "POST: TABLE FACTOR: t1",
+                    "PRE: TABLE FACTOR: t2",
                     "PRE: RELATION: t2",
                     "POST: RELATION: t2",
+                    "POST: TABLE FACTOR: t2",
                     "PRE: EXPR: t1.id = t2.t1_id",
                     "PRE: EXPR: t1.id",
                     "POST: EXPR: t1.id",
@@ -676,13 +726,17 @@ mod tests {
                 "SELECT * from t1 where EXISTS(SELECT column from t2)",
                 vec![
                     "PRE: STATEMENT: SELECT * FROM t1 WHERE EXISTS (SELECT column FROM t2)",
+                    "PRE: TABLE FACTOR: t1",
                     "PRE: RELATION: t1",
                     "POST: RELATION: t1",
+                    "POST: TABLE FACTOR: t1",
                     "PRE: EXPR: EXISTS (SELECT column FROM t2)",
                     "PRE: EXPR: column",
                     "POST: EXPR: column",
+                    "PRE: TABLE FACTOR: t2",
                     "PRE: RELATION: t2",
                     "POST: RELATION: t2",
+                    "POST: TABLE FACTOR: t2",
                     "POST: EXPR: EXISTS (SELECT column FROM t2)",
                     "POST: STATEMENT: SELECT * FROM t1 WHERE EXISTS (SELECT column FROM t2)",
                 ],
@@ -691,13 +745,17 @@ mod tests {
                 "SELECT * from t1 where EXISTS(SELECT column from t2)",
                 vec![
                     "PRE: STATEMENT: SELECT * FROM t1 WHERE EXISTS (SELECT column FROM t2)",
+                    "PRE: TABLE FACTOR: t1",
                     "PRE: RELATION: t1",
                     "POST: RELATION: t1",
+                    "POST: TABLE FACTOR: t1",
                     "PRE: EXPR: EXISTS (SELECT column FROM t2)",
                     "PRE: EXPR: column",
                     "POST: EXPR: column",
+                    "PRE: TABLE FACTOR: t2",
                     "PRE: RELATION: t2",
                     "POST: RELATION: t2",
+                    "POST: TABLE FACTOR: t2",
                     "POST: EXPR: EXISTS (SELECT column FROM t2)",
                     "POST: STATEMENT: SELECT * FROM t1 WHERE EXISTS (SELECT column FROM t2)",
                 ],
@@ -706,16 +764,22 @@ mod tests {
                 "SELECT * from t1 where EXISTS(SELECT column from t2) UNION SELECT * from t3",
                 vec![
                     "PRE: STATEMENT: SELECT * FROM t1 WHERE EXISTS (SELECT column FROM t2) UNION SELECT * FROM t3",
+                    "PRE: TABLE FACTOR: t1",
                     "PRE: RELATION: t1",
                     "POST: RELATION: t1",
+                    "POST: TABLE FACTOR: t1",
                     "PRE: EXPR: EXISTS (SELECT column FROM t2)",
                     "PRE: EXPR: column",
                     "POST: EXPR: column",
+                    "PRE: TABLE FACTOR: t2",
                     "PRE: RELATION: t2",
                     "POST: RELATION: t2",
+                    "POST: TABLE FACTOR: t2",
                     "POST: EXPR: EXISTS (SELECT column FROM t2)",
+                    "PRE: TABLE FACTOR: t3",
                     "PRE: RELATION: t3",
                     "POST: RELATION: t3",
+                    "POST: TABLE FACTOR: t3",
                     "POST: STATEMENT: SELECT * FROM t1 WHERE EXISTS (SELECT column FROM t2) UNION SELECT * FROM t3",
                 ],
             ),
