@@ -111,6 +111,7 @@ define_keywords!(
     BINARY,
     BLOB,
     BLOOMFILTER,
+    BOOL,
     BOOLEAN,
     BOTH,
     BTREE,
@@ -152,6 +153,7 @@ define_keywords!(
     COMMITTED,
     COMPRESSION,
     COMPUTE,
+    CONCURRENTLY,
     CONDITION,
     CONFLICT,
     CONNECT,
@@ -263,6 +265,8 @@ define_keywords!(
     FIRST,
     FIRST_VALUE,
     FLOAT,
+    FLOAT4,
+    FLOAT8,
     FLOOR,
     FOLLOWING,
     FOR,
@@ -307,6 +311,7 @@ define_keywords!(
     ILIKE,
     IMMUTABLE,
     IN,
+    INCLUDE,
     INCREMENT,
     INDEX,
     INDICATOR,
@@ -317,6 +322,9 @@ define_keywords!(
     INSENSITIVE,
     INSERT,
     INT,
+    INT2,
+    INT4,
+    INT8,
     INTEGER,
     INTERSECT,
     INTERSECTION,
@@ -502,6 +510,7 @@ define_keywords!(
     REPEATABLE,
     REPLACE,
     REPLICATION,
+    RESET,
     RESTRICT,
     RESULT,
     RETAIN,
